/* GLE - The GTK+ Layout Engine
 * Copyright (C) 1998 Tim Janik
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
#ifndef __GLE_H__
#define __GLE_H__


#include	"glemisc.h"
#include	"glepublic.h"


#ifdef __cplusplus
extern "C" {
#pragma }
#endif /* __cplusplus */



/* --- global variables --- */
extern	const guint	gle_libversion_major;
extern	const guint	gle_libversion_revision;
extern	const guint	gle_libversion_age;
extern	const gchar	*gle_libversion;


/* --- GLE main part --- */
void            gle_init                        (int            *argc,
						 char           ***argv);
const gchar*    gle_prg_name                    (void);
void            gle_finish                      (void);






#ifdef __cplusplus
#pragma {
}
#endif /* __cplusplus */


#endif	/* __GLE_H__ */
